"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseJson = exports.parseBooleanOrString = exports.parseBoolean = void 0;
const log = require("loglevel");
const helpers_1 = require("../helpers/helpers");
function parseBoolean(val, _default) {
    try {
        if (typeof val === 'boolean') {
            return val;
        }
        val = String(val);
        switch (val.toLocaleLowerCase()) {
            case 'true':
            case '1':
            case 'yes':
                return true;
            case 'false':
            case '0':
            case 'no':
                return false;
            default:
                return _default;
        }
    }
    catch (_) {
        return _default;
    }
}
exports.parseBoolean = parseBoolean;
function parseBooleanOrString(val) {
    switch (val) {
        case 'true':
            return true;
        case 'false':
            return false;
        default:
            return val;
    }
}
exports.parseBooleanOrString = parseBooleanOrString;
function parseJson(val) {
    if (!val)
        return {};
    try {
        return JSON.parse(val);
    }
    catch (err) {
        const windowsShellHint = helpers_1.isWindows()
            ? `\n   In particular, Windows cmd doesn't have single quotes, so you have to use only double-quotes plus escaping: "{\\"someKey\\": \\"someValue\\"}"`
            : '';
        log.error(`Unable to parse JSON value: ${val}\n` +
            `JSON should look like {"someString": "someValue", "someBoolean": true, "someArray": [1,2,3]}.\n` +
            ` - Only double quotes are allowed, single quotes are not.\n` +
            ` - Learn how your shell behaves and escapes characters.${windowsShellHint}\n` +
            ` - If unsure, validate your JSON using an online service.`);
        throw err;
    }
}
exports.parseJson = parseJson;
//# sourceMappingURL=parseUtils.js.map